@@ -5,7 +5,7 @@
 #' \code{bife} is used to fit fixed effects binary choice models (logit and probit) based on an unconditional likelihood approach.
 #' It is tailored for the fast estimation of binary choice models with potentially many individual fixed effects.
 #' The large dummy variable trap is avoided by a special iteratively reweighted least squares demeaning algorithm (Stammann, Heiss, and McFadden, 2016).
-#' The incidental parameter bias occuring in panels with shorter time horizons can be reduced by analytic or jackknife 
+#' The incidental parameter bias occuring in panels with shorter time horizons can be reduced by analytical 
 #' bias-correction (Newey and Hahn, 2004). If no bias-correction is applied, the estimated coefficients will be identical 
 #' to the ones obtained by \code{glm}. However, \code{bife} will compute faster than glm, if the model exhibits many fixed effects.
 #' 
@@ -14,8 +14,9 @@
 #' 
 #' @param 
 #' formula an object of class \code{"formula"} (or one that can be coerced to that class): a symbolic description of the model to be fitted.
-#' \code{formula} must be of type \eqn{y ~ x | id} where the \code{id} refers to an individual identifier. The formula can be extended with \code{fixed(z)} to account for
-#' multiple fixed effects (\eqn{y ~ x + fixed(z) | id}). See \code{fixed} for further details.
+#' \code{formula} must be of type \eqn{y ~ x | id} where the \code{id} refers to an individual identifier.
+#' The formula can be extended with \code{fixed(z)} to account for multiple fixed effects (\eqn{y ~ x + fixed(z) | id}).
+#' See \code{fixed} for further details.
 #'
 #' @param 
 #' data an optional data frame, list or environment (or object coercible by \code{as.data.frame} to a data frame) containing the variables in the model.
@@ -29,8 +30,8 @@
 #' naming the model function. The value should be any of \code{"logit"} or \code{"probit"}. Default is \code{"logit"}.
 #' 
 #' @param 
-#' bias_corr an optional string that specifies the type of the bias-correction: no bias-correction, analytical, jackknife. The value should 
-#' be any of \code{"no"}, \code{"ana"}, or \code{"jack"}. Default is \code{"ana"} (analytical).
+#' bias_corr an optional string that specifies the type of the bias-correction: no bias-correction or analytical. The value should 
+#' be any of \code{"no"} or \code{"ana"}. Default is \code{"ana"} (analytical).
 #' 
 #' @param 
 #' iter_demeaning an optional integer value that specifies the maximum number of iterations of the demeaning algorithm. Default is \code{100}. 
@@ -52,7 +53,7 @@
 #' A typical predictor has the form \eqn{response ~ terms | id} where response is the binary response vector (0-1 coded), terms is a series of terms
 #' which specifies a linear predictor for the response, and refers to an individual identifier. The linear predictor must not include any constant regressors due to the perfect collinearity
 #' with the fixed effects. Since individuals with a non-varying response do not contribute to the log likelihood they are dropped from the estimation
-#' procedure (unlike \code{glm}). The analytical and jackknife bias-correction follow Newey and Hahn (2004).
+#' procedure (unlike \code{glm}). The analytical bias-correction follows Newey and Hahn (2004).
 #' 
 #' Details for iter_demeaning and tol_demeaning: A special iteratively reweighted least squares demeaning algorithm is used following 
 #' Stammann, A., F. Heiss, and D. McFadden (2016). The stopping criterion is defined as \eqn{||b(i) - b(i - 1)|| < tol_demeaning}. 
@@ -67,18 +68,18 @@
 #'   \item{$alpha}{a vector of the uncorrected fixed effects}
 #'   \item{$se_beta}{a vector of the standard errors of the uncorrected structural parameters}
 #'   \item{$se_alpha}{a vector of the standard errors of the uncorrected fixed effects}
-#'   \item{$beta_vcoc}{a matrix of the covariance matrix of the uncorrected structural parameters}
+#'   \item{$beta_vcov}{a matrix of the covariance matrix of the uncorrected structural parameters}
 #'   \item{$avg_alpha}{the average of the uncorrected fixed effects}
 #'  \item{par_corr}{}  
 #'   \item{$beta}{a vector of the bias-corrected structural parameters}
 #'   \item{$alpha}{a vector of the bias-adjusted fixed effects}
 #'   \item{$se_beta}{a vector of the standard errors of the bias-corrected structural parameters}
 #'   \item{$se_alpha}{a vector of the standard errors of the bias-adjusted fixed effects}
-#'   \item{$beta_vcoc}{a matrix of the covariance matrix of the bias-corrected structural parameters}
+#'   \item{$beta_vcov}{a matrix of the covariance matrix of the bias-corrected structural parameters}
 #'   \item{$avg_alpha}{the average of the bias-adjusted fixed effects}
 #'  \item{logl_info}{}
 #'   \item{$nobs}{number of observations}  
-#'   \item{$df}{degrees of freedom}
+#'   \item{$k}{number of loglikelihood parameters}
 #'   \item{$loglik}{the log likelihood value given the uncorrected parameters}
 #'   \item{$events}{number of events}
 #'   \item{$iter_demeaning}{the number of iterations of the demeaning algorithm}
@@ -163,7 +164,7 @@
 #' Formula Formula model.part
 #' 
 #' @importFrom
-#' stats model.frame model.response model.matrix update aggregate
+#' stats aggregate coef model.frame model.matrix model.response plogis pnorm update 
 #' 
 #' @useDynLib 
 #' bife, .registration = TRUE 
@@ -181,13 +182,12 @@ bife <- function(formula, data = list(),
  
   # Checking input arguments
   if(model != "logit" && model != "probit") stop("'model' must be 'logit' or 'probit'.")
-  if(bias_corr != "no" && bias_corr != "ana" && bias_corr != "jack") stop("'bias_corr' must be 'no', 'ana', or 'jack'.")
+  if(bias_corr != "no" && bias_corr != "ana") stop("'bias_corr' must be 'no' or 'ana'.")
   
   # Update formula and drop missing values
   formula <- Formula(formula)
   mf <- model.frame(formula = formula, data = data)
   if(ncol(model.part(formula, data = mf, rhs = 2)) != 1) stop("'id' uncorrectly specified.")
-  drop_NA <- length(attr(mf, "na.action"))
    
   # Ordering data
   mf <- mf[order(mf[[ncol(mf)]]), ]
@@ -198,10 +198,14 @@ bife <- function(formula, data = list(),
   id <- model.part(formula, data = mf, rhs = 2)[[1]]
    
   # Perfectly classified: avg in {0,1}
-  mean_tab <- aggregate(y ~ id, FUN = mean)
-  mean_y <- mean_tab[, 2]
-  index_pc <- which(id %in% mean_tab[(mean_y > 0 & mean_y < 1), 1])
-  drop_pc <- length(y) - length(index_pc)
+  mean_table <- aggregate(y ~ id, FUN = mean)
+  mean_y <- mean_table[, 2]
+  index_pc <- which(id %in% mean_table[(mean_y > 0 & mean_y < 1), 1])
+  
+  # Store information
+  nobs <- length(y)
+  d <- ncol(X)
+  events <- sum(y)
    
   # Drop perfectly classified
   y <- y[index_pc]
@@ -211,17 +215,17 @@ bife <- function(formula, data = list(),
   # Set starting values if needed and check dimension if specified
   if(is.null(beta_start)) {
     
-    beta_start <- numeric(ncol(X))
+    beta_start <- numeric(d)
   } else {
     
-    if(length(beta_start) != ncol(X)) stop("'beta_start' must be of same dimension as the number of structural parameters.")
+    if(length(beta_start) != d) stop("'beta_start' must be of same dimension as the number of structural parameters.")
   }
    
   # Map "model"
   switch(model, logit = model_int <- 0, probit = model_int <- 1)
    
   # Map "bias_corr"
-  switch(bias_corr, no = bias_corr_int <- 0, ana = bias_corr_int <- 1, jack = bias_corr_int <- 2)
+  switch(bias_corr, no = bias_corr_int <- 0, ana = bias_corr_int <- 1)
    
   # Start algorithm
   result <- .bife(y = y, X = X, id = id,
@@ -231,12 +235,15 @@ bife <- function(formula, data = list(),
                   iter_max2 = iter_offset, tolerance2 = tol_offset)
    
   # Complete list
-  result$model_info$drop_NA  <- drop_NA
-  result$model_info$drop_pc  <- drop_pc
-  result$model_info$formula  <- formula
-  result$model_info$str_name <- attr(X, "dimnames")[[2]]
-  result$model_info$model  <- model
-  result$model_info$bias_corr  <- bias_corr
+  result[["logl_info"]][["nobs"]] <- nobs
+  result[["logl_info"]][["k"]] <- d + length(mean_y)
+  result[["logl_info"]][["events"]] <- events
+  result[["model_info"]][["drop_NA"]] <- length(attr(mf, "na.action"))
+  result[["model_info"]][["drop_pc"]] <- nobs - length(index_pc)
+  result[["model_info"]][["formula"]] <- formula
+  result[["model_info"]][["str_name"]] <- attr(X, "dimnames")[[2]]
+  result[["model_info"]][["model"]] <- model
+  result[["model_info"]][["bias_corr"]] <- bias_corr
    
    
   # Return list
